package com.ruoyi.mall.service;

import java.util.List;
import java.util.Map;

import com.ruoyi.common.utils.ApiResult;
import com.ruoyi.mall.domain.MallMemberCart;

/**
 * 购物车Service接口
 *
 * @author chang
 * @date 2021-11-25
 */
public interface IMallMemberCartService
{

    /**
     * 商品列表修改数量
     * @param param
     * @return
     */
    public ApiResult goodsListEditCount(Map<String,Object> param);

    /**
     * 查询购物车
     *
     * @param id 购物车主键
     * @return 购物车
     */
    public MallMemberCart selectMallMemberCartById(Long id);

    /**
     * 查询购物车列表
     *
     * @param mallMemberCart 购物车
     * @return 购物车集合
     */
    public List<MallMemberCart> selectMallMemberCartList(MallMemberCart mallMemberCart);

    /**
     * 新增购物车
     *
     * @param mallMemberCart 购物车
     * @return 结果
     */
    public int insertMallMemberCart(MallMemberCart mallMemberCart);

    /**
     * 修改购物车
     *
     * @param mallMemberCart 购物车
     * @return 结果
     */
    public int updateMallMemberCart(MallMemberCart mallMemberCart);

    /**
     * 批量删除购物车
     *
     * @param ids 需要删除的购物车主键集合
     * @return 结果
     */
    public int deleteMallMemberCartByIds(Long[] ids);

    /**
     * 删除购物车信息
     *
     * @param id 购物车主键
     * @return 结果
     */
    public int deleteMallMemberCartById(Long id);

    public void removeByUserIdAndCardIds(String cartsId, String userId);

    public MallMemberCart selectMallMemberCartByCart(MallMemberCart cart);
}
