package com.ruoyi.mall.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.mall.domain.MallMemberCart;
import com.ruoyi.mall.service.IMallMemberCartService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 购物车Controller
 * 
 * @author chang
 * @date 2021-11-25
 */
@RestController
@RequestMapping("/mall/mallMemberCart")
public class MallMemberCartController extends BaseController
{
    @Autowired
    private IMallMemberCartService mallMemberCartService;

    /**
     * 查询购物车列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallMemberCart:list')")
    @GetMapping("/list")
    public TableDataInfo list(MallMemberCart mallMemberCart)
    {
        startPage();
        List<MallMemberCart> list = mallMemberCartService.selectMallMemberCartList(mallMemberCart);
        return getDataTable(list);
    }

    /**
     * 导出购物车列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallMemberCart:export')")
    @Log(title = "购物车", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(MallMemberCart mallMemberCart)
    {
        List<MallMemberCart> list = mallMemberCartService.selectMallMemberCartList(mallMemberCart);
        ExcelUtil<MallMemberCart> util = new ExcelUtil<MallMemberCart>(MallMemberCart.class);
        return util.exportExcel(list, "购物车数据");
    }

    /**
     * 获取购物车详细信息
     */
    @PreAuthorize("@ss.hasPermi('mall:mallMemberCart:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(mallMemberCartService.selectMallMemberCartById(id));
    }

    /**
     * 新增购物车
     */
    @PreAuthorize("@ss.hasPermi('mall:mallMemberCart:add')")
    @Log(title = "购物车", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MallMemberCart mallMemberCart)
    {
        return toAjax(mallMemberCartService.insertMallMemberCart(mallMemberCart));
    }

    /**
     * 修改购物车
     */
    @PreAuthorize("@ss.hasPermi('mall:mallMemberCart:edit')")
    @Log(title = "购物车", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MallMemberCart mallMemberCart)
    {
        return toAjax(mallMemberCartService.updateMallMemberCart(mallMemberCart));
    }

    /**
     * 删除购物车
     */
    @PreAuthorize("@ss.hasPermi('mall:mallMemberCart:remove')")
    @Log(title = "购物车", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(mallMemberCartService.deleteMallMemberCartByIds(ids));
    }
}
